@@ -1,10 +1,13 @@
+import os
+import sys
+sys.path.append(os.path.abspath(os.path.join(os.path.dirname(__file__), "../")))
 import torch
 import torch.nn as nn
 from . import BasicModule
-from ..module import Embedding
-from ..module import GCN as GCNBlock
+from module import Embedding
+from module import GCN as GCNBlock
 
-from ..utils import seq_len_to_mask
+from utils import seq_len_to_mask
 
 
 class GCN(BasicModule):
